@@ -87,7 +87,7 @@ QString FilterActionWithCommand::substituteCommandLineArgsFor(const KMime::Messa
     }
 
     // sort the list of n's
-    qSort(argList);
+    std::sort(argList.begin(), argList.end());
 
     // and use QString::arg to substitute filenames for the %n's.
     int lastSeen = -2;
@@ -108,7 +108,7 @@ QString FilterActionWithCommand::substituteCommandLineArgsFor(const KMime::Messa
 
             QFile file(tempFileName);
             if (!file.open(QIODevice::WriteOnly)) {
-                qCWarning(MAILCOMMON_LOG) << "Faild to write message to file: " << file.errorString();
+                qCWarning(MAILCOMMON_LOG) << "Failed to write message to file: " << file.errorString();
                 tempFile->close();
                 continue;
             }
@@ -141,9 +141,7 @@ QString FilterActionWithCommand::substituteCommandLineArgsFor(const KMime::Messa
     return result;
 }
 
-namespace
-{
-
+namespace {
 /**
  * Substitutes placeholders in the command line with the
  * content of the correspoding header in the message.
@@ -156,7 +154,7 @@ void substituteMessageHeaders(const KMime::Message::Ptr &aMsg, QString &result)
     QRegExp header_rx(QStringLiteral("%\\{([a-z0-9-]+)\\}"), Qt::CaseInsensitive);
     int idx = 0;
     while ((idx = header_rx.indexIn(result, idx)) != -1) {
-        const KMime::Headers::Base *header = aMsg->headerByType(header_rx.cap(1).toLatin1());
+        const KMime::Headers::Base *header = aMsg->headerByType(header_rx.cap(1).toLatin1().constData());
         QString replacement;
         if (header) {
             replacement = KShell::quoteArg(QString::fromLatin1(header->as7BitString()));
@@ -176,7 +174,6 @@ void substituteCommandLineArgsForItem(const Akonadi::Item &item, QString &comman
     commandLine.replace(QLatin1String("%{itemurl}"), item.url(Akonadi::Item::UrlWithMimeType).url());
     commandLine.replace(QLatin1String("%{itemid}"), QString::number(item.id()));
 }
-
 }
 
 FilterAction::ReturnCode FilterActionWithCommand::genericProcess(ItemContext &context, bool withOutput) const
@@ -215,7 +212,7 @@ FilterAction::ReturnCode FilterActionWithCommand::genericProcess(ItemContext &co
     // the user may have specified. In the long run, we
     // shouldn't be using tempfiles at all for this class, due
     // to security aspects. (mmutz)
-    commandLine =  QLatin1Char('(') + commandLine + QLatin1String(") <") + inFile->fileName();
+    commandLine = QLatin1Char('(') + commandLine + QLatin1String(") <") + inFile->fileName();
 
     // write message to file
     QString tempFileName = inFile->fileName();
@@ -284,4 +281,3 @@ FilterAction::ReturnCode FilterActionWithCommand::genericProcess(ItemContext &co
 
     return GoOn;
 }
-
