@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -108,9 +108,6 @@ public:
 
     Q_REQUIRED_RESULT EntityCollectionOrderProxyModel *entityOrderProxy() const;
 
-    void quotaWarningParameters(const QColor &color, qreal threshold);
-    void readQuotaConfig();
-
     Q_REQUIRED_RESULT QLineEdit *filterFolderLineEdit() const;
     void applyFilter(const QString &);
     void clearFilter();
