@@ -153,7 +153,7 @@ void SearchRuleWidget::setPatternEditOptions(SearchPatternEdit::SearchPatternEdi
 void SearchRuleWidget::initWidget(SearchPatternEdit::SearchModeType modeType)
 {
     QHBoxLayout *hlay = new QHBoxLayout(this);
-    hlay->setMargin(0);
+    hlay->setContentsMargins(0, 0, 0, 0);
 
     // initialize the header field combo box
     mRuleField = new PimCommon::MinimumComboBox(this);
@@ -396,12 +396,12 @@ void SearchRuleWidget::initFieldList(SearchPatternEdit::SearchPatternEditOptions
 
     // these others only represent message headers and you can add to
     // them as you like
-    mFilterFieldList.append(QLatin1String("List-Id"));
-    mFilterFieldList.append(QLatin1String("Resent-From"));
-    mFilterFieldList.append(QLatin1String("X-Loop"));
-    mFilterFieldList.append(QLatin1String("X-Mailing-List"));
-    mFilterFieldList.append(QLatin1String("X-Spam-Flag"));
-    mFilterFieldList.append(QLatin1String("X-Spam-Status"));
+    mFilterFieldList.append(QStringLiteral("List-Id"));
+    mFilterFieldList.append(QStringLiteral("Resent-From"));
+    mFilterFieldList.append(QStringLiteral("X-Loop"));
+    mFilterFieldList.append(QStringLiteral("X-Mailing-List"));
+    mFilterFieldList.append(QStringLiteral("X-Spam-Flag"));
+    mFilterFieldList.append(QStringLiteral("X-Spam-Status"));
 }
 
 void SearchRuleWidget::slotRuleFieldChanged(const QString &field)
@@ -432,7 +432,8 @@ SearchRuleWidgetLister::~SearchRuleWidgetLister()
 void SearchRuleWidgetLister::setPatternEditOptions(SearchPatternEdit::SearchPatternEditOptions options)
 {
     mOptions = options;
-    foreach (QWidget *w, widgets()) {
+    const auto lst = widgets();
+    for (QWidget *w : lst) {
         qobject_cast<SearchRuleWidget *>(w)->setPatternEditOptions(options);
     }
 }
@@ -569,7 +570,8 @@ void SearchRuleWidgetLister::regenerateRuleListFromWidgets()
 
     mRuleList->clear();
 
-    foreach (const QWidget *w, widgets()) {
+    const auto lst = widgets();
+    for (const QWidget *w : lst) {
         SearchRule::Ptr r = qobject_cast<const SearchRuleWidget *>(w)->rule();
         if (r && !r->isEmpty()) {
             mRuleList->append(r);
@@ -610,7 +612,7 @@ void SearchPatternEdit::setPatternEditOptions(SearchPatternEdit::SearchPatternEd
 void SearchPatternEdit::initLayout(SearchPatternEditOptions options, SearchModeType modeType)
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     const bool matchAllMessages = (options & MailCommon::SearchPatternEdit::MatchAllMessages);
     //------------the radio buttons
